==> python-anilist-1.0.8.tar.gz: python-anilist-1.0.8/CHANGELOG.md <==
<!--
  ~ Copyright (C) 2021-2022 Amano Team <https://amanoteam.com/>
  ~ 
  ~ SPDX-License-Identifier: MIT
  -->

# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## 1.0.8 (February 16th, 2022)

### Added

- `.relations` for animes and mangas.

### Changed

- Separate queries into separate files.
- Happy new year (late).

## 1.0.7 (January 18th, 2022)

### Added

- Pagination.
- `rewatched` and `reread` activity status.

### Changed

- Fix .vscode gitignore.
- Fix user and staff search queries.
- Update get_activity type error.

## 1.0.6 (October 20th, 2021)

### Added

- Support for `Python 3.10`.

### Changed

- Fixed subpackages.

## 1.0.5 (August 4th, 2021)

### Added

- List get query.
- Staff get query.
- Staff search query.
- User search query.
- Fixed message activity.
- Added `alternative` attribute to the Name object.
- Message activities.
- Support for users, favourites, staff, statistics, rankings, and studios.
- Support for user list and text activities.

### Changed

- Fixed typos & bugs.
- Added `is_adult` to both anime and manga objects.
- Added user object to text activities.
- Added profile colors and other fields to the user object.
- Added timestamps to the date object.
- Tidied up and organized required fields in every object.

## 1.0.4 (April 5th, 2021)

### Changed

- Hotfix, fix a typo on get manga.

## 1.0.3 (April 4th, 2021)

### Added

- Support for characters.

### Changed

- HTTP2 enabled (async mode only).

## 1.0.2 (March 8th, 2021)

### Added

- Support for mangas.

### Changed

- Some bug fixes.

## 1.0.1 (March 8th, 2021)

### Changed

- Bug fixes.

## 1.0.0 (March 8th, 2021)

* First release

==> python-anilist-1.0.9.tar.gz: python-anilist-1.0.9/CHANGELOG.md <==
<!--
  ~ Copyright (C) 2021-2022 Amano Team <https://amanoteam.com/>
  ~ 
  ~ SPDX-License-Identifier: MIT
  -->

# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## 1.0.9 (February 16th, 2022)

### Added

- hotfix: queries: add missing `pageInfo` from https://github.com/AmanoTeam/python-anilist/commit/2c9f7efd5127371fd09b6630c1564c13755131d1.

## 1.0.8 (February 16th, 2022)

### Added

- `.relations` for animes and mangas.

### Changed

- Separate queries into separate files.
- Happy new year (late).

## 1.0.7 (January 18th, 2022)

### Added

- Pagination.
- `rewatched` and `reread` activity status.

### Changed

- Fix .vscode gitignore.
- Fix user and staff search queries.
- Update get_activity type error.

## 1.0.6 (October 20th, 2021)

### Added

- Support for `Python 3.10`.

### Changed

- Fixed subpackages.

## 1.0.5 (August 4th, 2021)

### Added

- List get query.
- Staff get query.
- Staff search query.
- User search query.
- Fixed message activity.
- Added `alternative` attribute to the Name object.
- Message activities.
- Support for users, favourites, staff, statistics, rankings, and studios.
- Support for user list and text activities.

### Changed

- Fixed typos & bugs.
- Added `is_adult` to both anime and manga objects.
- Added user object to text activities.
- Added profile colors and other fields to the user object.
- Added timestamps to the date object.
- Tidied up and organized required fields in every object.

## 1.0.4 (April 5th, 2021)

### Changed

- Hotfix, fix a typo on get manga.

## 1.0.3 (April 4th, 2021)

### Added

- Support for characters.

### Changed

- HTTP2 enabled (async mode only).

## 1.0.2 (March 8th, 2021)

### Added

- Support for mangas.

### Changed

- Some bug fixes.

## 1.0.1 (March 8th, 2021)

### Changed

- Bug fixes.

## 1.0.0 (March 8th, 2021)

* First release
